require 'spec_helper'

describe Chute::V2::Album::Asset do
  before do
    stub_const 'Chute::Client', double('Chute::Client')
  end

  context "GET" do
    let(:album_id) { 'album_id' }
    let(:asset_id) { 'asset_id' }

    it "should get all assets" do
      expect(Chute::Client).to receive(:get).with "/v2/albums/#{album_id}/assets", {}

      Chute::V2::Album::Asset.all album_id
    end

    it "find a specific asset" do
      expect(Chute::Client).to receive(:get).with "/v2/albums/#{album_id}/assets/#{asset_id}"

      Chute::V2::Album::Asset.find album_id, asset_id
    end

    context 'With params' do
      let(:params) { { per_page: 1, page: 2 } }

      it "should get all assets" do
        expect(Chute::Client).to receive(:get).with "/v2/albums/#{album_id}/assets", params

        Chute::V2::Album::Asset.all album_id, params
      end
    end
  end

  context "PUT" do
    let(:album_id) { 'album_id' }
    let(:asset_id) { 'asset_id' }
    let(:data) { { asset: { tags: [ 'foo', 'bar' ] } } }

    it "should update the asset" do
      expect(Chute::Client).to receive(:put).with "/v2/albums/#{album_id}/assets/#{asset_id}", data

      Chute::V2::Album::Asset.update album_id, asset_id, data
    end

    context 'When the data is not wrapped in the asset key' do
      it "should wrap and update the asset" do
        expect(Chute::Client).to receive(:put).with "/v2/albums/#{album_id}/assets/#{asset_id}", data

        Chute::V2::Album::Asset.update album_id, asset_id, data[:asset]
      end
    end
  end
end
