require 'spec_helper'

describe Chute::V2::Asset::Meta do
  context "PUT" do
    before do
      stub_const 'Chute::Client', double('Chute::Client')
    end

    let(:album_id) { 'album_id' }
    let(:asset_id) { 'asset_id' }
    let(:meta) { { metadata: { foo: 'bar' } } }

    context 'Public' do
      it "should store the metadata" do
        expect(Chute::Client).to receive(:put).with "/v2/albums/#{album_id}/assets/#{asset_id}/meta/public", meta

        Chute::V2::Asset::Meta.public album_id, asset_id, meta
      end
    end

    context 'Private' do
      it "should store the metadata" do
        expect(Chute::Client).to receive(:put).with "/v2/albums/#{album_id}/assets/#{asset_id}/meta/private", meta

        Chute::V2::Asset::Meta.private album_id, asset_id, meta
      end
    end

    context 'When the data is not wrapped in the metadata key' do
      context 'Public' do
        it "should wrap and store the metadata" do
          expect(Chute::Client).to receive(:put).with "/v2/albums/#{album_id}/assets/#{asset_id}/meta/public", meta

          Chute::V2::Asset::Meta.public album_id, asset_id, meta[:metadata]
        end
      end

      context 'Private' do
        it "should wrap and store the metadata" do
          expect(Chute::Client).to receive(:put).with "/v2/albums/#{album_id}/assets/#{asset_id}/meta/private", meta

          Chute::V2::Asset::Meta.private album_id, asset_id, meta[:metadata]
        end
      end
    end
  end
end
